## Bash Script: Sequential File Release Automation

### Purpose:
This script automates the process of "releasing" the next sequential file in a specified directory. Hidden files (prefixed with a dot `.`) are renamed to remove the leading dot, making them visible. It is designed to be executed periodically via a **cron job**, simulating the timed release of new episodes for a show.

---

### Script Breakdown:

#### 1. Shebang and Description
```bash
#!/bin/bash

# This script when executed through a cronjob, will unhide the next sequential file in the given directory.
# This emulates the (frequency) release of a new episode.
```
- `#!/bin/bash`: Specifies the Bash shell for executing the script.
- The comment describes the script's purpose and typical use case.

---

#### 2. Process Files for "Season 1"
```bash
file="$(find /local/path/to/media/server/show/season.01/ -type f -iname ".*" | sort | head -n1)" &&
mv "$file" "/local/path/to/media/server/show/season.01/${file##*/.}" ;
```
- **Step 1**: Finds all hidden files (starting with `.`) in the `season.01` directory:
  - `find`: Searches files in the given directory.
  - `-type f`: Restricts the search to regular files.
  - `-iname ".*"`: Matches filenames starting with a dot, ignoring case.
- **Step 2**: Sorts the hidden files alphabetically.
- **Step 3**: Selects the first file in the sorted list (`head -n1`).
- **Step 4**: Renames the selected file by removing the leading dot using:
  - `${file##*/.}`: Removes the directory path and leading dot from the filename.
- **Step 5**: Moves the file back to the same directory with its new name (unhidden).

---

#### 3. Process Files for "Season 4"
```bash
file="$(find /local/path/to/media/server/show/season.04/ -type f -iname ".*" | sort | head -n1)" &&
mv "$file" "/local/path/to/media/server/show/season.04/${file##*/.}" ;
```
- Repeats the same process for the `season.04` directory.

---

#### 4. Source Script Reference
```bash
# This is the source script
#file="$(find /path -type f -iname ".*" | sort | head -n1)"
#mv "$file" "/path/${file##*/.}";
```
- The commented lines show a generic version of the script for reference or future customization.

---

### Key Concepts:
1. **Hidden Files**: Files prefixed with a dot (`.`) are considered hidden in Unix-like systems.
2. **Cron Jobs**: The script is intended to run periodically, e.g., once a week or daily, to emulate timed releases.
3. **File Renaming**: The script unhides the next file by removing the leading dot from its name.

---

### Requirements:
1. **Directories and Files**: Ensure the specified directories (`season.01` and `season.04`) contain hidden files.
2. **Permissions**: Ensure the script has appropriate permissions to access and modify files.
3. **Cron Setup**: Add the script to a cron job with a suitable frequency:
   ```bash
   0 9 * * * /path/to/script.sh
   ```
   This example runs the script daily at 9:00 AM.

---

### Enhancements:
1. **Logging**: Add logging to record which files were released and when.
   ```bash
   echo "$(date): Released $(basename "$file")" >> /path/to/logfile.log
   ```
2. **Error Handling**: Add checks for missing files or errors during file renaming.
3. **Configuration File**: Store directory paths in a configuration file for easier maintenance.

---

### Example Output:
- Before:
  ```
  .episode01.mkv
  .episode02.mkv
  ```
- After first execution:
  ```
  episode01.mkv
  .episode02.mkv
  ```
- After second execution:
  ```
  episode01.mkv
  episode02.mkv
  ```

--- 

This script is an efficient way to simulate scheduled releases for media files, making it suitable for automation scenarios.
